# -*- coding: UTF-8 -*-
# Copyright 2015 Mahmoud Mamdouh
# License: BSD (see file COPYING for details)


from __future__ import unicode_literals
__author__ = 'drx'

def populate(p):
    p.city("Giza", "الجيزة", "")
    p.city("Al Haram", "الهرم", "")
    p.city("King Faisel", "الملك فيصل", "")
    p.city("Memphis", "ممفيس", "")
    p.city("6th of October", "السادس من اكتوبر", "")
    p.city("Sheikh Zayed", "الشيخ زايد", "")
    p.city("Others", "اخرى", "")