# -*- coding: UTF-8 -*-
# Copyright 2015 Mahmoud Mamdouh
# License: BSD (see file COPYING for details)


from __future__ import unicode_literals
__author__ = 'drx'

def populate(p):
    p.city("Damietta", "دمياط", "")
    p.city("Ras El Bar", "رأس البر", "")
    p.city("New Damietta", "دمياط الجديدة", "")
    p.city("Faraskur", "فارسكور", "")
    p.city("Al Zarqa", "الزرقا", "")
    p.city("Kafr Saad", "كفر سعد", "")
    p.city("Others", "اخرى", "")