# -*- coding: UTF-8 -*-
# Copyright 2015 Mahmoud Mamdouh
# License: BSD (see file COPYING for details)


from __future__ import unicode_literals
__author__ = 'drx'

def populate(p):
    p.city("Alexandria","الإسكندري")
    p.city("Montazah","المنتزة")
    p.city("Alexandria Shark (East)","شرق الإسكندرية")
    p.city("Alexandria Wassat (Middle)","غرب الإسكندرية")
    p.city("Gomrok","الجمرك")
    p.city("Agami","العجمي")
    p.city("Amriya","الاميرية")
    p.city("Borg El Arab","برج العرب")
    p.city("Others","اخرى")