# -*- coding: UTF-8 -*-
# Copyright 2015 Mahmoud Mamdouh
# License: BSD (see file COPYING for details)


from __future__ import unicode_literals
__author__ = 'drx'

def populate(p):
    p.city("El-Marg", "المرج", "")
    p.city("Al Salam", "السلام", "")
    p.city("Ain Shams", "عين شمس", "")
    p.city("Al-Matariyyah", "المطرية", "")
    p.city("Al Zeitoun", "الزيتون" , "")
    p.city("Haddaq Al Qubbah", "حدائق القبة", "")
    p.city("Al Nuzhah", "النزهة", "")
    p.city("Misr Al Jadidah", "مصر الجديدة", "")
    p.city("Al Waili", "الوايلي", "")
    p.city("Al Zawiyah Al Hamra", "الزاوية الحمراء", "")
    p.city("Al Sharabiyah", "الشرابية", "")
    p.city("Al Sajil", "السجل", "")
    p.city("Shobra", "شبرا", "")
    p.city("Rud Al Faraj", "روض الفرج", "")
    p.city("Bulaq", "بولاق", "")
    p.city("Al Azbakeya", "الأزبكية", "")
    p.city("Manshiyat Naser", "منشية نصر", "")
    p.city("Mokattam", "المقطم", "")
    p.city("Madinat Nasr", "مدينة نصر", "")
    p.city("Qasr al Nil", "قصر النيل", "")
    p.city("Al Zamalek", "الزمالك", "")
    p.city("Abdin", "عبدين", "")
    p.city("Al Muski", "الموسكي", "")
    p.city("Bab Al-Shaariyah", "باب الشعرية", "")
    p.city("Al Azhar", "الأزهر", "")
    p.city("Al Jamaliyah", "الجمالية", "")
    p.city("Al-Darb al Ahmar", "الدرب الأحمر", "")
    p.city("Al Sayidah Zaynab", "السيد زينب", "")
    p.city("Misr Al Qadimah", "مصر القديمة", "")
    p.city("Al Khalifa", "الخليفة", "")
    p.city("Al Basatin", "البساتين", "")
    p.city("Maadi", "المعادي", "")
    p.city("Turah", "طرة", "")
    p.city("15 May", "15 مايو", "")
    p.city("Helwan", "حلوان", "")
    p.city("Al-Tabin", "التبين", "")
    p.city("Qahirah al Jadidah", "القاهرة الجديدة", "")
    p.city("Al Shuruq", "الشروق", "")
    p.city("Badr", "بدر", "")
    p.city("Others", "اخرى", "")