# -*- coding: UTF-8 -*-
# Copyright 2015 Mahmoud Mamdouh
# License: BSD (see file COPYING for details)


from __future__ import unicode_literals
__author__ = 'drx'

def populate(p):
    p.city("Port Said", "بورسعيد", "")
    p.city("Port Fouad", "بورفؤاد", "")
    p.city("Others", "اخرى", "")